Learn R Programming

dnet (version 1.0.0)

dEnricher: Function to conduct enrichment analysis given the input data and the ontology in query

Description

dEnricher is supposed to conduct enrichment analysis given the input data and the ontology in query. It returns an object of class "eTerm". Enrichment analysis is based on either Fisher's exact test or Hypergeometric test. The test can respect the hierarchy of the ontology.

Usage

dEnricher(data, identity = c("symbol", "entrez"),
check.symbol.identity = FALSE, genome = c("Hs", "Mm", "Rn", "Gg", "Ce",
"Dm", "Da", "At"), ontology = c("GOBP", "GOMF", "GOCC", "PS", "DO",
"HPPA",
"HPMI", "HPON", "MP", "MsigdbC1", "MsigdbC2CGP", "MsigdbC2CP",
"MsigdbC2KEGG",
"MsigdbC2REACTOME", "MsigdbC2BIOCARTA", "MsigdbC3TFT", "MsigdbC3MIR",
"MsigdbC4CGN", "MsigdbC4CM", "MsigdbC5BP", "MsigdbC5MF", "MsigdbC5CC",
"MsigdbC6", "MsigdbC7"), sizeRange = c(10, 1000), which_distance =
NULL,
test = c("FisherTest", "HypergeoTest", "BinomialTest"),
p.adjust.method = c("BH", "BY", "bonferroni", "holm", "hochberg",
"hommel"),
ontology.algorithm = c("none", "pc", "elim", "lea"), elim.pvalue =
0.01,
lea.depth = 2, verbose = T,
RData.location = "http://dnet.r-forge.r-project.org/data")

Arguments

data
an input vector. It contains either Entrez Gene ID or Symbol
identity
the type of gene identity (i.e. row names of input data), either "symbol" for gene symbols (by default) or "entrez" for Entrez Gene ID. The option "symbol" is preferred as it is relatively stable from one update to another; also it is possible to search a
check.symbol.identity
logical to indicate whether synonyms will be searched against when gene symbols cannot be matched. By default, it sets to FALSE since it may take a while to do such check using all possible synoyms
genome
the genome identity. It can be one of "Hs" for human, "Mm" for mouse, "Rn" for rat, "Gg" for chicken, "Ce" for c.elegans, "Dm" for fruitfly, "Da" for zebrafish, and "At" for arabidopsis
ontology
the ontology supported currently. It can be "GOBP" for Gene Ontology Biological Process, "GOMF" for Gene Ontology Molecular Function, "GOCC" for Gene Ontology Cellular Component, "PS" for phylostratific age information, "DO" for Disease Ontology, "HPPA" f
sizeRange
the minimum and maximum size of members of each gene set in consideration. By default, it sets to a minimum of 10 but no more than 1000
which_distance
which distance of terms in the ontology is used to restrict terms in consideration. By default, it sets to 'NULL' to consider all distances
test
the statistic test used. It can be "FisherTest" for using fisher's exact test, "HypergeoTest" for using hypergeometric test, or "BinomialTest" for using binomial test. Fisher's exact test is to test the independence between gene group (genes belonging to
p.adjust.method
the method used to adjust p-values. It can be one of "BH", "BY", "bonferroni", "holm", "hochberg" and "hommel". The first two methods "BH" (widely used) and "BY" control the false discovery rate (FDR: the expected proportion of false discoveries amongst t
ontology.algorithm
the algorithm used to account for the hierarchy of the ontology. It can be one of "none", "pc", "elim" and "lea". For details, please see 'Note'
elim.pvalue
the parameter only used when "ontology.algorithm" is "elim". It is used to control how to declare a signficantly enriched term (and subsequently all genes in this term are eliminated from all its ancestors)
lea.depth
the parameter only used when "ontology.algorithm" is "lea". It is used to control how many maximum depth is uded to consider the children of a term (and subsequently all genes in these children term are eliminated from the use for the recalculation of the
verbose
logical to indicate whether the messages will be displayed in the screen. By default, it sets to false for no display
RData.location
the characters to tell the location of built-in RData files. By default, it remotely locates at "http://dnet.r-forge.r-project.org/data". For the user equipped with fast internet connection, this option can be just left as default. But it is al

Value

  • an object of class "eTerm", a list with following components:
    • set_info: a matrix of nSet X 4 containing gene set information, where nSet is the number of gene set in consideration, and the 4 columns are "setID" (i.e. "Term ID"), "name" (i.e. "Term Name"), "namespace" and "distance"
  • gs: a list of gene sets, each storing gene members. Always, gene sets are identified by "setID" and gene members identified by "Entrez ID"
  • data: a vector containing input data in consideration. It is not always the same as the input data as only those mappable are retained
  • zscore: a vector containing z-scores
  • pvalue: a vector containing p-values
  • adjp: a vector containing adjusted p-values. It is the p value but after being adjusted for multiple comparisons
  • call: the call that produced this result

See Also

dEnricher

Examples

Run this code
load(url("http://dnet.r-forge.r-project.org/data/Datasets/Hiratani_TableS1.RData"))
data <- rownames(RT)[1:1000]
# fisher's exact test (witout accounting for ontology hierarchy)
eTerm <- dEnricher(data, identity="symbol", genome="Mm", ontology="MP",
RData.location="./RData_Rd")
# fisher's exact test (using 'pc' algorithm to account for ontology hierarchy)
eTerm <- dEnricher(data, identity="symbol", genome="Mm", ontology="MP",
ontology.algorithm="pc", RData.location="./RData_Rd")
# fisher's exact test (using 'elim' algorithm to account for ontology hierarchy)
eTerm <- dEnricher(data, identity="symbol", genome="Mm", ontology="MP",
ontology.algorithm="elim", RData.location="./RData_Rd")
# fisher's exact test (using 'lea' algorithm to account for ontology hierarchy)
eTerm <- dEnricher(data, identity="symbol", genome="Mm", ontology="MP",
ontology.algorithm="lea", RData.location="./RData_Rd")

# visualise the top significant terms in the ontology heirarchy
load(url("http://dnet.r-forge.r-project.org/data/Obo/ig.MP.RData"))
g <- ig.MP
nodes_query <- names(sort(eTerm$adjp)[1:5])
nodes.highlight <- rep("red", length(nodes_query))
names(nodes.highlight) <- nodes_query
subg <- dDAGinduce(g, nodes_query)
# color-code terms according to the adjust p-values (taking the form of 10-based negative logarithm)
visDAG(g=subg, data=-1*log10(eTerm$adjp[V(subg)$name]),
node.info="both", zlim=c(0,2), node.attrs=list(color=nodes.highlight))
# color-code terms according to the z-scores
visDAG(g=subg, data=eTerm$zscore[V(subg)$name], node.info="both",
colormap="darkblue-white-darkorange",
node.attrs=list(color=nodes.highlight))

Run the code above in your browser using DataLab