Learn R Programming

dnet (version 1.0.0)

dNetReorder: Function to reorder the multiple graph colorings within a sheet-shape rectangle grid

Description

dNetReorder is reorder the multiple graph colorings within a sheet-shape rectangle grid

Usage

dNetReorder(g, data, feature = c("node", "edge"), node.normalise =
c("none",
"degree"), xdim = NULL, ydim = NULL, amplifier = NULL,
metric = c("none", "pearson", "spearman", "kendall", "euclidean",
"manhattan", "cos", "mi"), init = c("linear", "uniform", "sample"),
algorithm = c("sequential", "batch"), alphaType = c("invert", "linear",
"power"), neighKernel = c("gaussian", "bubble", "cutgaussian", "ep",
"gamma"))

Arguments

g
an object of class "igraph" or "graphNEL"
data
an input data matrix used to color-code vertices/nodes. One column corresponds to one graph node coloring. The input matrix must have row names, and these names should include all node names of input graph, i.e. V(g)$name, since there is a mapping operati
feature
the type of the features used. It can be one of either 'edge' for the edge feature or 'node' for the node feature.
node.normalise
the normalisation of the nodes. It can be one of either 'none' for no normalisation or 'degree' for a node being penalised by its degree.
xdim
an integer specifying x-dimension of the grid
ydim
an integer specifying y-dimension of the grid
amplifier
an integer specifying the amplifier (3 by default) of the number of component planes. The product of the component number and the amplifier constitutes the number of rectangles in the sheet grid
metric
distance metric used to define the similarity between component planes. It can be "none", which means directly using column-wise vectors of codebook/data matrix. Otherwise, first calculate the covariance matrix from the codebook/data matrix. The distance
init
an initialisation method. It can be one of "uniform", "sample" and "linear" initialisation methods
algorithm
the training algorithm. Currently, only "sequential" algorithm has been implemented
alphaType
the alpha type. It can be one of "invert", "linear" and "power" alpha types
neighKernel
the training neighbor kernel. It can be one of "gaussian", "bubble", "cutgaussian", "ep" and "gamma" kernels

Value

  • an object of class "sReorder", a list with following components:
    • nHex: the total number of rectanges in the grid
  • xdim: x-dimension of the grid
  • ydim: y-dimension of the grid
  • uOrder: the unique order/placement for each component plane that is reordered to the "sheet"-shape grid with rectangular lattice
  • coord: a matrix of nHex x 2, with each row corresponding to the coordinates of each "uOrder" rectangle in the 2D map grid
  • call: the call that produced this result

See Also

visNetReorder

Examples

Run this code
# 1) generate a random graph according to the ER model
g <- erdos.renyi.game(100, 1/100)

# 2) produce the induced subgraph only based on the nodes in query
subg <- dNetInduce(g, V(g), knn=0)

# 3) reorder the module with vertices being color-coded by input data
nnodes <- vcount(subg)
nsamples <- 10
data <- matrix(runif(nnodes*nsamples), nrow=nnodes, ncol=nsamples)
rownames(data) <- V(subg)$name
sReorder <- dNetReorder(g=subg, data, feature="node",
node.normalise="none")

Run the code above in your browser using DataLab