Usage
visDAG(g, data = NULL, height = 7, width = 7, margin = rep(0.1, 4),
colormap = c("lightyellow-orange", "yr", "bwr", "jet", "gbr", "wyr",
"br",
"rainbow", "wb"), ncolors = 40, zlim = NULL, colorbar = T,
colorbar.fraction = 0.1, newpage = T,
layout.orientation = c("left_right", "top_bottom", "bottom_top",
"right_left"), node.info = c("none", "term_id", "term_name", "both",
"full_term_name"), graph.node.attrs = NULL, graph.edge.attrs = NULL,
node.attrs = NULL)Arguments
g
an object of class "igraph"
data
a named input data verctor used to color-code
vertices/nodes. The input data vector must have names,
and these names should include all node names of input
graph, i.e. V(g)$name, since there is a mapping
operation. The way of how to color-code is to map v
height
a numeric value specifying the height of
device
width
a numeric value specifying the width of
device
margin
margins as units of length 4 or 1
colormap
short name for the colormap. It can be
one of "jet" (jet colormap), "bwr" (blue-white-red
colormap), "gbr" (green-black-red colormap), "wyr"
(white-yellow-red colormap), "br" (black-red colormap),
"yr" (yellow-red colormap), "wb" (white-black colormap),
a
ncolors
the number of colors specified over the
colormap
zlim
the minimum and maximum z/data values for
which colors should be plotted, defaulting to the range
of the finite values of z. Each of the given colors will
be used to color an equispaced interval of this range.
The midpoints of the intervals cover the rang
colorbar
logical to indicate whether to append a
colorbar. If data is null, it always sets to false
colorbar.fraction
the relative fraction of
colorbar block against the device size
newpage
logical to indicate whether to open a new
page. By default, it sets to true for opening a new page
layout.orientation
the orientation of the DAG
layout. It can be one of "left_right" for the left-right
layout (viewed from the DAG root point), "top_bottom" for
the top-bottom layout, "bottom_top" for the bottom-top
layout, and "right_left" for the right-left layout
node.info
tells the ontology term information used
to label nodes. It can be one of "none" for no node
labeling, "term_id" for using Term ID, "term_name" for
using Term Name (the first 15 characters), "both" for
using both of Term ID and Name (the first 15 characte
graph.node.attrs
a list of global node attributes.
These node attributes will be changed globally. See
'Note' below for details on the attributes
graph.edge.attrs
a list of global edge attributes.
These edge attributes will be changed globally. See
'Note' below for details on the attributes
node.attrs
a list of local edge attributes. These
node attributes will be changed locally; as such, for
each attribute, the input value must be a named vector
(i.e. using Term ID as names). See 'Note' below for
details on the attributes